@@ -18,10 +18,6 @@
  * MA 02110-1301 USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <gio/gio.h>
 #include <libxfce4util/libxfce4util.h>
 
