@@ -30,10 +30,6 @@
  * error dialogs and more.
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
