@@ -28,10 +28,6 @@
  * with as-you-type checking for invalid filenames.
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
