@@ -27,10 +27,6 @@
  * Common used functions for GtkWidget's that are not provided by the Gtk+ library
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
