@@ -28,10 +28,6 @@
  * Functions to spawn a command with startup notification support.
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
