@@ -28,10 +28,6 @@
  * subtitle and mixed or pixbuf buttons.
  **/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_STDARG_H
 #include <stdarg.h>
 #endif
