@@ -17,9 +17,6 @@
  * MA 02110-1301 USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #ifdef HAVE_XFCE_REVISION_H
 #include "xfce-revision.h"
 #endif
@@ -291,7 +288,9 @@ main (int argc, char **argv)
               xfce_die_error ("The file \"%s\" contains no data", argv[1]);
             }
 
-          return EXIT_FAILURE;
+          g_free (contents);
+          result = EXIT_FAILURE;
+          goto out;
         }
 
       /* load the data into the key file */
@@ -303,7 +302,8 @@ main (int argc, char **argv)
           /* failed to parse the file */
           xfce_die_error ("Failed to parse contents of \"%s\": %s", argv[1], error->message);
           g_error_free (error);
-          return EXIT_FAILURE;
+          result = EXIT_FAILURE;
+          goto out;
         }
     }
 
@@ -314,7 +314,8 @@ main (int argc, char **argv)
     {
       /* we cannot continue without a type */
       xfce_die_error ("File \"%s\" has no type key", argv[1]);
-      return EXIT_FAILURE;
+      result = EXIT_FAILURE;
+      goto out;
     }
 
   /* verify that we support the type */
@@ -324,7 +325,9 @@ main (int argc, char **argv)
     {
       /* tell the user that we don't support the type */
       xfce_die_error ("Unsupported desktop file type \"%s\"", value);
-      return EXIT_FAILURE;
+      g_free (value);
+      result = EXIT_FAILURE;
+      goto out;
     }
   g_free (value);
   mode = enum_value->value;
@@ -435,7 +438,10 @@ main (int argc, char **argv)
       break;
     }
 
-    /* check if a parent window id was specified */
+  /* set initial size request from text entry contents */
+  xfce_die_editor_set_size_request (XFCE_DIE_EDITOR (editor));
+
+  /* check if a parent window id was specified */
 #ifdef ENABLE_X11
   if (G_UNLIKELY (opt_xid != 0 && GDK_IS_X11_DISPLAY (gdk_display_get_default ())))
     {
@@ -681,10 +687,6 @@ main (int argc, char **argv)
   /* destroy the editor dialog */
   gtk_widget_destroy (dialog);
 
-  /* cleanup */
-  g_key_file_free (key_file);
-  g_object_unref (G_OBJECT (gfile));
-
   if (result == EXIT_SUCCESS && result_file != NULL && opt_print_saved_uri)
     {
       gchar *uri = g_file_get_uri (result_file);
@@ -697,5 +699,10 @@ main (int argc, char **argv)
       g_object_unref (result_file);
     }
 
+out:
+  /* cleanup */
+  g_key_file_free (key_file);
+  g_object_unref (G_OBJECT (gfile));
+
   return result;
 }
